FloatingViewTheme class

A theme for the FloatingView.

Constructors

FloatingViewTheme({double elevation = 2, Color? backgroundColor, double radius = 12})
Creates a FloatingViewTheme.
const

Properties

backgroundColor → Color?
The background color of the floating widget.
final
elevation → double
The elevation of the floating widget.
final
hashCode → int
The hash code for this object.
no setterinherited
radius → double
The border radius of the floating widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited