FloatingView class

A widget that provides a floating, draggable, and resizable widget overlay.

The FloatingView is a stateful widget that allows you to overlay a floating widget on top of your existing UI. The floating widget can be dragged around, resized, and toggled between a collapsed and expanded state.

The floating widget's position, size, and behavior are controlled by a FloatingController which must be provided to the FloatingView.

The appearance of the floating widget can be customized using the FloatingViewTheme.

The FloatingView requires a childBuilder function that builds the main content of the widget, and a controller to manage the floating widget's state.

Example usage:

FloatingView(
  childBuilder: () => YourMainWidget(),
  controller: FloatingController(),
  theme: FloatingViewTheme(
    elevation: 8.0,
    backgroundColor: Colors.white,
    radius: 16.0,
  ),
)

See also:

Inheritance

Constructors

FloatingView({Key? key, required Widget childBuilder(), required FloatingController controller, FloatingViewTheme theme = const FloatingViewTheme()})
const

Properties

childBuilder → Widget Function()
final
controller → FloatingController
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → FloatingViewTheme
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FloatingViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited